mallorca_transit_services library
An unofficial Dart package for the Balearic Islands' Public Transportation services. It provides a simple way to access Mallorca's transportation services and get information about the bus stops, lines, schedules, etc.
Classes
- BusPosition
- Real-time bus position received from the location WebSocket.
- BusStopped
- Event received from the location WebSocket when a bus stops at a station.
- ConnectionClose
- Sent by the WebSocket when the bus reaches its final destination.
- Departure
- DeparturesApi
- LocationWebSocket
- WebSocket client for real-time bus tracking.
- NewsScraper
-
Scrapes news detail pages from
RssItemlinks. - Passangers
- RealTrip
- RealTripBusStats
- RouteHoliday
- Holidays that may affect the schedule of a route line.
- RouteLine
- RouteLinesApi
- RoutePath
- A route path with a list of coordinate segments for a given Subline.
- RouteSession
- RouteStationInfo
- Real-time route snapshot received from the location WebSocket. Contains current passenger counts and the ordered list of stops.
- RouteTown
- Station
- StationOnRoute
- StationsApi
- Subline
- TransitRss
- TransitWarningScraper
-
Scrapes warning detail pages from
RssItemlinks.
Enums
- Language
- Supported feed languages.
- LineType
- PickupDropoffType
- Way