BusPosition class

Real-time bus position received from the location WebSocket.

Constructors

BusPosition({required double lat, required double long, double? speed, required DateTime timestamp})
BusPosition.fromJson(Map json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
lat double
final
long double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double?
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited