Departure class

Constructors

Departure({required DateTime departureTime, required DateTime estimatedArrival, required String name, required int tripId, RealTrip? realTrip, required bool delayed, required String lineCode, String? destination, String? departureStop})
Departure.fromJson(Map json)
factory

Properties

delayed bool
getter/setter pair
departureStop String?
getter/setter pair
departureTime DateTime
getter/setter pair
destination String?
getter/setter pair
estimatedArrival DateTime
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lineCode String
getter/setter pair
name String
getter/setter pair
realTrip RealTrip?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tripId int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toJson(Departure departure) Map