DeparturesApi class

Constructors

DeparturesApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

httpClient ↔ Client
getter/setter pair

Static Methods

getDepartures({required String stationCode, required int numberOfDepartures}) Future<List<Departure>>
Throws FormatException for an invalid station code, Exception if no departures are found.