LocationWebSocket class

WebSocket client for real-time bus tracking.

Constructors

LocationWebSocket()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

locationChannel(int id) → WebSocketChannel
locationParser(Map json) Object
Parses a WebSocket message into the appropriate model. Types: positionBusPosition, esta-infoRouteStationInfo, stopBusStopped, closeConnectionClose.
locationStream(int id) Stream