RealTrip class

Constructors

RealTrip({DateTime? estimatedArrival, required double lat, required double long, required int id, RealTripBusStats? stats})
RealTrip.fromJson(Map json)
factory

Properties

estimatedArrival DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
lat double
getter/setter pair
long double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stats RealTripBusStats?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toJson(RealTrip realTrip) String