RealTripBusStats class

Constructors

RealTripBusStats({required int placesToSit, required int placesToStand, required int passengers})
RealTripBusStats.fromJson(Map json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
passengers int
Total number of passengers currently in the bus
getter/setter pair
placesToSit int
Total number of places to sit in the bus (counting occupied and free)
getter/setter pair
placesToStand int
Total number of places to stand in the bus (counting occupied and free)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toJson(RealTripBusStats realTripBusStats) Map