RouteLine class

Constructors

RouteLine({required bool active, required String code, required int id, required String name, required int color, List<Subline>? sublines, required LineType type, bool? summerOnly, List<RouteSession>? sessions, List<RouteTown>? towns, List<RouteHoliday>? holidays, List<int>? zoneIds, bool? onDemand})
RouteLine.fromJson(Map json)
factory

Properties

active bool
getter/setter pair
code String
getter/setter pair
color int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
holidays List<RouteHoliday>?
getter/setter pair
id int
getter/setter pair
name String
getter/setter pair
onDemand bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessions List<RouteSession>?
getter/setter pair
sublines List<Subline>?
getter/setter pair
summerOnly bool?
getter/setter pair
towns List<RouteTown>?
getter/setter pair
type LineType
getter/setter pair
zoneIds List<int>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toJson(RouteLine line) Map