RouteLinesApi class

Constructors

RouteLinesApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

httpClient ↔ Client
getter/setter pair

Static Methods

getAllLines({bool activeOnly = false}) Future<List<RouteLine>>
getLine(String lineCode) Future<RouteLine>
getPath(Subline subline) Future<RoutePath>
getPdfTimetable(String lineCode, {int? lineId}) Future<Uri?>
Fetches the URL of the most recent PDF timetable for the given lineCode.
getSublines(RouteLine line, [bool onlyActive = true]) Future<List<Subline>>
Pass onlyActive false to include inactive sublines.