RouteStationInfo class

Real-time route snapshot received from the location WebSocket. Contains current passenger counts and the ordered list of stops.

Constructors

RouteStationInfo({required Passangers passangers, required List<StationOnRoute> stops})
RouteStationInfo.fromJson(Map json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
passangers Passangers
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stops List<StationOnRoute>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited