Station class

Constructors

Station({required String code, required int id, required double lat, required double long, required String name, String? ref})
Station.fromJson(Map json)
factory

Properties

code String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
lat double
getter/setter pair
long double
getter/setter pair
name String
getter/setter pair
ref String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toJson(Station station) Map