StationOnRoute class
Constructors
- StationOnRoute({required int stopId, required String stopName, required DateTime scheduledArrival, double? estimatedDistance, DateTime? estimatedArrival})
- StationOnRoute.fromJson(Map json)
-
factory
Properties
- estimatedArrival ↔ DateTime?
-
getter/setter pair
- estimatedDistance ↔ double?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduledArrival ↔ DateTime
-
getter/setter pair
- stopId ↔ int
-
getter/setter pair
- stopName ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited