StationsApi class

Constructors

StationsApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

httpClient ↔ Client
getter/setter pair

Static Methods

fromId(int id) Future<Station>
getAllStations({int count = -1}) Future<List<Station>>
Pass count to limit results; -1 returns all stations (default).
getLines(String stationCode) Future<List<RouteLine>>
Use Station.code, not Station.id.