Subline class

Constructors

Subline({required RouteLine parentLine, required bool active, required String code, required int id, required String name, required int color, required LineType type, required List<Station> stations, required Way way, List<RouteTown>? towns, bool? main, double? distance})
Subline.fromJson(Map json, RouteLine mainRouteLine)
factory

Properties

active bool
getter/setter pair
code String
getter/setter pair
color int
getter/setter pair
distance double?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
main bool?
getter/setter pair
name String
getter/setter pair
parentLine RouteLine
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stations List<Station>
getter/setter pair
towns List<RouteTown>?
getter/setter pair
type LineType
getter/setter pair
way Way
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toJson(Subline subline) Map