mallorca_transit_services library
An unofficial Dart package for the Balearic Islands' Public Transportation services. It provides a simple way to access Mallorca's transportation services and get information about the bus stops, lines, schedules, etc.
Classes
- BusPosition
- Represents the position of a bus. It is received by the location socket and is used to track the bus.
- BusStopped
- Represents the bus stop at a station.
- ConnectionClose
- ConnectionClose is a class that represents the event of a connection being closed. Usually this event is sent when the bus has arrived at the final destination.
- Departure
- A departure from the departures list.
- Departures
- LocationWebSocket
- A class that connects to the location socket and returns the stream of messages.
- NewsScraper
- A class that scrapes the news feed. The scrapeNewsDescription method scrapes the news description. The scrapeNewsImage method scrapes the news image.
- Passangers
- Represents the number of passengers in the bus and the total capacity of the bus.
- RealTrip
- A class that represents a real-time trip from a Departure. A real-time trip has an estimated arrival time, a latitude, and a longitude.
- RealTripBusStats
- RouteLine
- RoutePath
-
A class that represents a route path.
A route path has a subline and a list of paths.
Each path is a list of coordinates.
The coordinates are represented by a
LatLngobject. The subline parameter is the subline of the route path. - RouteStationInfo
- Received data from the server about the bus route and the stations on the route.
- Station
- A class that represents a station.
- StationOnRoute
- Represents a station on the route.
- Subline
- TransitRss
- A class that represents the RSS feed. The feed has a list of items. Each item is a warning or news article. The getWarningFeed method returns the warning feed. The getNewsFeed method returns the news feed.
- TransitWarningScraper
- A class that scrapes the warning feed. The scrapeWarningDescription method scrapes the warning description. The scrapeAffectedLines method scrapes the affected lines.