Passangers class
Constructors
- Passangers({required int inBus, required int totalCapacity, int? seatedCapacity, int? standingCapacity})
- Passangers.fromJson(Map json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inBus → int
-
May exceed totalCapacity when the bus is overcrowded.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seatedCapacity → int?
-
final
- standingCapacity → int?
-
final
- totalCapacity → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited