RouteHoliday class
Holidays that may affect the schedule of a route line.
Only returned by RouteLinesApi.getLine, not by RouteLinesApi.getAllLines.
Constructors
- RouteHoliday({required DateTime date, required String name})
- RouteHoliday.fromJson(Map json)
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
toJson(
RouteHoliday holiday) → Map