RouteSession class
Constructors
- RouteSession({String? busTypeId, required bool current, required DateTime startDate, required DateTime endDate, required String name})
- RouteSession.fromJson(Map json)
-
factory
Properties
- busTypeId ↔ String?
-
getter/setter pair
- current ↔ bool
-
getter/setter pair
- endDate ↔ DateTime
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate ↔ DateTime
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
toJson(
RouteSession session) → Map